==> 0.0.6.tar.gz: lib/src/orientdb_server_base.dart <==
// Copyright (c) 2015, <your name>. All rights reserved. Use of this source code
// is governed by a BSD-style license that can be found in the LICENSE file.


library orientdb_server.base;

import 'dart:async';
import 'dart:io';
import 'dart:convert';
/// Checks if you are awesome. Spoiler: you are.
class Awesome {
  bool get isAwesome => true;
}

class OrientDB_UrlParts {
  String userName;
  String password;
  String host;
  int port;

  OrientDB_UrlParts(this.userName, this.password, this.host, this.port);

  String shortToString() => "$host:$port";
  String longToString() => "$userName:$password@$host:$port";
}

Future<List> databaseList(OrientDB_UrlParts urlParts) {
  List list = new List();
  var completer = new Completer();
  HttpClient client = new HttpClient();
  client.getUrl(Uri.parse("http://${urlParts.shortToString()}/listDatabases")).then((clientRequest) {
    return clientRequest.close();
  }).then((clientResponse) {
    clientResponse.transform(UTF8.decoder).listen((contents) {
      var json = JSON.decode(contents);
      for (String database in json['databases']) {
        list.add(database);
      }
      completer.complete(list);

    });
  });
  return completer.future;

}



class Storage {
  const LOCAL = "plocal";
  const MEMORY = "memory";
}




class DBType {
  const DOCUMENT = "document";
  const GRAPH = "graph";
}

CreateDatabase(OrientDB_UrlParts urlParts, String database, Storage storage, DBType databaseType) {
  HttpClient client = new HttpClient();
  client.postUrl(Uri.parse("http://${urlParts.longToString()}/database/$database/$storage/$databaseType"))
  .then((clientRequest){
    return clientRequest.close();
  }).then((clientResponse) {
    clientResponse.transform(UTF8.decoder).listen((_) {});
  });
}

==> 0.0.7.tar.gz: lib/src/orientdb_server_base.dart <==
// Copyright (c) 2015, <your name>. All rights reserved. Use of this source code
// is governed by a BSD-style license that can be found in the LICENSE file.


library orientdb_server.base;

import 'dart:async';
import 'dart:io';
import 'dart:convert';
/// Checks if you are awesome. Spoiler: you are.
class Awesome {
  bool get isAwesome => true;
}

class OrientDB_UrlParts {
  String userName;
  String password;
  String host;
  int port;

  OrientDB_UrlParts(this.userName, this.password, this.host, this.port);

  String shortToString() => "$host:$port";
  String longToString() => "$userName:$password@$host:$port";
}

Future<List> databaseList(OrientDB_UrlParts urlParts) {
  List list = new List();
  var completer = new Completer();
  HttpClient client = new HttpClient();
  client.getUrl(Uri.parse("http://${urlParts.shortToString()}/listDatabases")).then((clientRequest) {
    return clientRequest.close();
  }).then((clientResponse) {
    clientResponse.transform(UTF8.decoder).listen((contents) {
      var json = JSON.decode(contents);
      for (String database in json['databases']) {
        list.add(database);
      }
      completer.complete(list);

    });
  });
  return completer.future;

}


class Storage {
  static final LOCAL = 'plocal';
  static final MEMORY = 'memory';
}




class DBType {
  static final DOCUMENT = "document";
  static final GRAPH = "graph";
}

CreateDatabase(OrientDB_UrlParts urlParts, String database, Storage storage, DBType databaseType) {
  HttpClient client = new HttpClient();
  client.postUrl(Uri.parse("http://${urlParts.longToString()}/database/$database/$storage/$databaseType"))
  .then((clientRequest){
    return clientRequest.close();
  }).then((clientResponse) {
    clientResponse.transform(UTF8.decoder).listen((_) {});
  });
}
